@@ -1,8 +1,6 @@
-Arima = function (x, order = c(0, 0, 0), seasonal = list(order = c(0,
-    0, 0), period = NA), xreg = NULL, include.mean = TRUE, include.drift = FALSE,
-    transform.pars = TRUE, fixed = NULL, init = NULL, method = c("CSS-ML",
-        "ML", "CSS"), n.cond, optim.control = list(), kappa = 1e+06,
-    model = NULL)
+Arima = function (x, order = c(0, 0, 0), seasonal = list(order = c(0, 0, 0), period = NA), xreg = NULL, 
+ include.mean = TRUE, include.drift = FALSE, transform.pars = TRUE, fixed = NULL, init = NULL, 
+  method = c("CSS-ML", "ML", "CSS"), n.cond, optim.control = list(), kappa = 1e+06, model = NULL)
 {
     if (!is.null(model))
         return(arima2(x, model))
